@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the affinity between two people
 
-our $VERSION = '0.0110';
+our $VERSION = '0.0111';
 
 use Moo;
 use strictures 2;
@@ -104,7 +104,7 @@ Acme::Affinity - Compute the affinity between two people
 
 =head1 VERSION
 
-version 0.0110
+version 0.0111
 
 =head1 SYNOPSIS
 
@@ -163,11 +163,12 @@ Example:
   [ [ 'very organized',  'very organized',  'very important' ],
     [ 'no',              'no',              'a little important' ], ]
 
-So person A ("me") considers themself to be very organized, desires a
-very organized person, and this is a very important to them.
+So person A ("me") considers him or herself to be "very organized",
+desires a "very organized" person, and this is "very important" to
+them.
 
-Person A also does not need to be the center of attention, desires the
-same type of person, but this is only a little important.
+Person A also does not need to be the "center of attention", desires
+the same type of person, but this is only "a little important."
 
 =head2 you
 
@@ -181,11 +182,12 @@ Example:
   [ [ 'very organized',  'average',  'a little important' ],
     [ 'yes',             'no',       'somewhat important' ], ]
 
-Person B considers themself to be very organized, but only desires
-someone who is average, and this is only a little important to them.
+Person B considers him or herself to be "very organized", but only
+desires someone who is "average", and this is only "a little
+important" to them.
 
-Person B likes to be the center of attention, desires someone who does
-not, and this is somewhat important.
+Person B likes to be the "center of attention", desires someone who
+does not, and this is "somewhat important."
 
 =head1 METHODS
 
